<h1 align="center">rAPId-sdk</h1>

<p align="center">
<a>
<img src="https://github.com/no10ds/rapid-api/actions/workflows/main.yml/badge.svg">
</a>
<a href="https://pypi.org/project/rapid-sdk" target="_blank">
<img src="https://img.shields.io/pypi/v/rapid-sdk?color=%2334D058&label=pypi%20package" alt="Package version">
</a>
</p>

# About
rAPId-sdk is a Python wrapper for the rapid-api repository. It provides a simple and intuitive interface for accessing the functionality of the rapid-api library in Python.

# Contributing

To install rAPId sdk, you will need to have pyenv and python installed. You can use the provided Makefile to set up the required dependencies and create a virtual environment for the project:

```
make setup
```

This will install pyenv and the specified version of python, create a virtual environment for the project, and install the required dependencies.

To create a test deployment and upload the package to testpypi run `make deploy/test`

# License

rAPId api is released under the MIT License.
